summaryrefslogtreecommitdiffstats
path: root/kig/objects/curve_imp.h
diff options
context:
space:
mode:
Diffstat (limited to 'kig/objects/curve_imp.h')
-rw-r--r--kig/objects/curve_imp.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kig/objects/curve_imp.h b/kig/objects/curve_imp.h
index a0b130cc..3a33a722 100644
--- a/kig/objects/curve_imp.h
+++ b/kig/objects/curve_imp.h
@@ -51,12 +51,12 @@ public:
virtual CurveImp* copy() const = 0;
/**
* Return whether this Curve tqcontains the given point. This is
* implemented as a numerical approximation. Implementations
* can/should use the value test_threshold in common.h as a
* threshold value.
*/
- virtual bool tqcontainsPoint( const Coordinate& p, const KigDocument& ) const = 0;
+ virtual bool containsPoint( const Coordinate& p, const KigDocument& ) const = 0;
};
#endif
@@ -51,12 +51,12 @@ public:
virtual CurveImp* copy() const = 0;
/**
- * Return whether this Curve tqcontains the given point. This is
+ * Return whether this Curve contains the given point. This is
* implemented as a numerical approximation. Implementations
* can/should use the value test_threshold in common.h as a